#!/bin/bash

# Function to handle script termination
cleanup() {
    # Remove the temporary file
    if [ -f "$temp_file" ]; then
        rm -f "$temp_file"
    fi
    exit 0
}

# Trap the termination signals
trap cleanup SIGINT SIGTERM

# Check if the required arguments are provided
if [ $# -ne 3 ]; then
    echo "Usage: $0 <timestamp in seconds> <connection name> <short/long>"
    exit 1
fi

log_file="/var/log/pluto.log"
db="/opt/tcr/ipsec_reasons.conf"
timestamp=$1
context=$2
period=$3

# Calculate the start and end timestamps based on the search type
case $period in
    "short")
        # Convert the timestamp to the pluto date format
        date_str1=$(date -d "@$(($timestamp - 1))" +"%b %d %T")
        date_str2=$(date -d @$timestamp +"%b %d %T")
        ;;
    "long")
        # Convert the timestamp to the pluto date format
        date_str1=$(date -d "@$(($timestamp - 60))" +"%b %d %H:%M")
        date_str2=$date_str1
        ;;
    *)
        echo "Invalid search type. Please specify 'short' or 'long'."
        exit 1
        ;;
esac


# Check if the log file exists
if [ ! -f "$log_file" ]; then
    echo "Log file does not exist: $log_file"
    exit 1
fi

# Check if the databse file exists
if [ ! -f "$db" ]; then
    echo "database file does not exist: $db"
    exit 1
fi

# Create a temporary file to store the relevant section of the log file
temp_file=$(mktemp)

grep -e "$date_str1" -e "$date_str2" $log_file | grep "$context" | tac > "$temp_file"

# Read the failure reasons from the database
while IFS='$' read -r pattern output; do
    if [[ $pattern == \#* ]]; then
        continue
    fi
    # Use grep to find the first line matching the pattern in the temporary file
    matched_line=$(grep -m 1 -E "$pattern" "$temp_file")

    # If a match is found, print the match and the human readable string and exit the loop
    if [ -n "$matched_line" ]; then
        echo $matched_line
        echo $output
        cleanup
    fi
done < "$db"

echo "unknown"